@@ -1,8 +1,7 @@
-/* $Id: context.c,v 1.79 2000/07/19 20:58:59 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  3.3
+ * Version:  3.4
  *
  * Copyright (C) 1999-2000  Brian Paul   All Rights Reserved.
  *
@@ -211,10 +210,11 @@ _mesa_initialize_visual( GLvisual *vis,
 
    if (depthBits == 0) {
       /* Special case.  Even if we don't have a depth buffer we need
-       * good values for DepthMax for Z vertex transformation purposes.
+       * good values for DepthMax for Z vertex transformation purposes
+       * and for per-fragment fog computation.
        */
-      vis->DepthMax = 1;
-      vis->DepthMaxF = 1.0F;
+      vis->DepthMax = 1 << 16;
+      vis->DepthMaxF = (GLfloat) vis->DepthMax;
    }
    else if (depthBits < 32) {
       vis->DepthMax = (1 << depthBits) - 1;
@@ -412,10 +412,10 @@ one_time_init( void )
       _mesa_init_fog();
       _mesa_init_math();
       gl_init_lists();
-      gl_init_shade();
       gl_init_texture();
       gl_init_transformation();
       gl_init_translate();
+      gl_init_shade();
       gl_init_vbrender();
       gl_init_vbxform();
       gl_init_vertices();
@@ -452,9 +452,13 @@ alloc_shared_state( void )
    if (!ss)
       return NULL;
 
-   ss->DisplayList = _mesa_NewHashTable();
+   _glthread_INIT_MUTEX(ss->Mutex);
 
+   ss->DisplayList = _mesa_NewHashTable();
    ss->TexObjects = _mesa_NewHashTable();
+#ifdef VAO
+   ss->ArrayObjects = _mesa_NewHashTable();
+#endif
 
    /* Default Texture objects */
    outOfMemory = GL_FALSE;
@@ -593,6 +597,8 @@ init_texture_unit( GLcontext *ctx, GLuint unit )
 {
    struct gl_texture_unit *texUnit = &ctx->Texture.Unit[unit];
 
+   texUnit->Enabled = 0;
+   texUnit->ReallyEnabled = 0;
    texUnit->EnvMode = GL_MODULATE;
    texUnit->CombineModeRGB = GL_MODULATE;
    texUnit->CombineModeA = GL_MODULATE;
@@ -1149,9 +1155,10 @@ init_attrib_groups( GLcontext *ctx )
    /* Texture group */
    ctx->Texture.CurrentUnit = 0;      /* multitexture */
    ctx->Texture.CurrentTransformUnit = 0; /* multitexture */
-   ctx->Texture.Enabled = 0;
+   ctx->Texture.ReallyEnabled = 0;
    for (i=0; i<MAX_TEXTURE_UNITS; i++)
       init_texture_unit( ctx, i );
+   ctx->Texture.SharedPalette = GL_FALSE;
    _mesa_init_colortable(&ctx->Texture.Palette);
 
    /* Transformation group */
@@ -1184,6 +1191,13 @@ init_attrib_groups( GLcontext *ctx )
    ctx->Viewport.WindowMap.type = MATRIX_3D_NO_ROT;
 
    /* Vertex arrays */
+#ifdef VAO
+   {
+      struct gl_array_object *arrayObj;
+      arrayObj = _mesa_alloc_vertex_array_object(ctx, 0);
+      ctx->Array.Current = arrayObj;
+   }
+#else
    ctx->Array.Vertex.Size = 4;
    ctx->Array.Vertex.Type = GL_FLOAT;
    ctx->Array.Vertex.Stride = 0;
@@ -1219,6 +1233,7 @@ init_attrib_groups( GLcontext *ctx )
    ctx->Array.EdgeFlag.StrideB = 0;
    ctx->Array.EdgeFlag.Ptr = NULL;
    ctx->Array.EdgeFlag.Enabled = GL_FALSE;
+#endif
    ctx->Array.ActiveTexture = 0;   /* GL_ARB_multitexture */
 
    /* Pixel transfer */
@@ -1376,7 +1391,8 @@ alloc_proxy_textures( GLcontext *ctx )
 
 
 /*
- * Initialize a GLcontext struct.
+ * Initialize a GLcontext struct.  This includes allocating all the
+ * other structs and arrays which hang off of the context by pointers.
  */
 GLboolean
 _mesa_initialize_context( GLcontext *ctx,
@@ -1399,7 +1415,6 @@ _mesa_initialize_context( GLcontext *ctx,
 
    ctx->VB = gl_vb_create_for_immediate( ctx );
    if (!ctx->VB) {
-      FREE( ctx );
       return GL_FALSE;
    }
    ctx->input = ctx->VB->IM;
@@ -1407,7 +1422,6 @@ _mesa_initialize_context( GLcontext *ctx,
    ctx->PB = gl_alloc_pb();
    if (!ctx->PB) {
       ALIGN_FREE( ctx->VB );
-      FREE( ctx );
       return GL_FALSE;
    }
 
@@ -1421,7 +1435,6 @@ _mesa_initialize_context( GLcontext *ctx,
       if (!ctx->Shared) {
          ALIGN_FREE( ctx->VB );
          FREE( ctx->PB );
-         FREE( ctx );
          return GL_FALSE;
       }
    }
@@ -1453,7 +1466,6 @@ _mesa_initialize_context( GLcontext *ctx,
       free_shared_state(ctx, ctx->Shared);
       ALIGN_FREE( ctx->VB );
       FREE( ctx->PB );
-      FREE( ctx );
       return GL_FALSE;
    }
 
@@ -1484,7 +1496,6 @@ _mesa_initialize_context( GLcontext *ctx,
       FREE( ctx->PB );
       if (ctx->Exec)
          FREE( ctx->Exec );
-      FREE( ctx );
    }
    _mesa_init_exec_table(ctx->Exec, dispatchSize);
    _mesa_init_dlist_table(ctx->Save, dispatchSize);
@@ -1879,7 +1890,11 @@ _mesa_get_dispatch(GLcontext *ctx)
 void gl_problem( const GLcontext *ctx, const char *s )
 {
    fprintf( stderr, "Mesa implementation error: %s\n", s );
-   fprintf( stderr, "Report to Mesa bug database at www.mesa3d.org\n" );
+#ifdef XF86DRI
+   fprintf( stderr, "Please report to the DRI bug database at dri.sourceforge.net\n");
+#else
+   fprintf( stderr, "Please report to the Mesa bug database at www.mesa3d.org\n" );
+#endif
    (void) ctx;
 }
 
